@@ -23,14 +23,8 @@ mod zymod_config;
 pub mod floatutils;
 pub mod stringutils;
 
-pub fn string_to_f32_converter(value: &str) -> f32 {
-    let change_value = (value).replace("\n", "").parse::<f32>().unwrap();
-    return change_value;
-}
-
 pub fn log_level_converter(log_level: i8) -> LevelFilter {
-    let number = log_level;
-    match number {
+    match log_level {
         1 => LevelFilter::Error,
         2 => LevelFilter::Warn,
         3 => LevelFilter::Info,
@@ -186,7 +180,9 @@ impl Zymod {
             log::info!("zymod：agentURL:{}", agent_address);
 
             run_time.block_on(async {
-                let mut client = ZhiYanClient::connect(agent_address).await.unwrap();
+                let mut client = ZhiYanClient::connect(agent_address)
+                    .await
+                    .expect("[Error]Agent连接失败");
 
                 let request = Request::new(ZhiYanRequest {
                     name: name.to_string(),
